@@ -648,6 +648,7 @@ get_tokens_and_identity (GoaOAuth2Provider  *provider,
       gchar *markup;
 
       escaped_url = g_markup_escape_text (url, -1);
+      /* Translators: The verb "Paste" is used when asking the user to paste a string from a web browser window */
       markup = g_strdup_printf (_("Paste authorization code obtained from the <a href=\"%s\">authorization page</a>:"),
                                 escaped_url);
       g_free (escaped_url);
@@ -1208,7 +1209,7 @@ goa_oauth2_provider_get_access_token_sync (GoaOAuth2Provider  *provider,
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_NOT_AUTHORIZED,
-                   _("Credentials does not contain access_token"));
+                   _("Credentials do not contain access_token"));
       goto out;
     }
 
